@@ -8,7 +8,6 @@ import sphinx
 import sphinx.util
 from sphinx.util.console import darkgreen, bold
 from sphinx.util.osutil import ensuredir
-from sphinx.util.docstrings import prepare_docstring
 import sphinx.util.logging
 import unidecode
 
@@ -35,7 +34,7 @@ class PythonMapperBase:
 
     Required attributes:
 
-    :var str id: A globally unique indentifier for this object.
+    :var str id: A globally unique identifier for this object.
                  Generally a fully qualified name, including namespace.
     :var str name: A short "display friendly" name for this object.
 
@@ -122,7 +121,7 @@ class PythonMapperBase:
         Slugs to a filename using the follow steps
 
         * Decode unicode to approximate ascii
-        * Remove existing hypens
+        * Remove existing hyphens
         * Substitute hyphens for non-word characters
         * Break up the string as paths
         """
@@ -190,7 +189,7 @@ class SphinxMapperBase:
         )
 
         def _wrapped_prepare(value):
-            return "\n".join(prepare_docstring(value))
+            return value
 
         self.jinja_env.filters["prepare_docstring"] = _wrapped_prepare
         if self.app.config.autoapi_prepare_jinja_env:
