@@ -61,7 +61,7 @@ class DotNetSphinxMapper(SphinxMapperBase):
     DOCFX_OUTPUT_PATH = "_api"
 
     # pylint: disable=arguments-differ
-    def load(self, patterns, dirs, ignore=None, **kwargs):
+    def load(self, patterns, dirs, ignore=None):
         """Load objects from the filesystem into the ``paths`` dictionary.
 
         If the setting ``autoapi_patterns`` was not specified, look for a
@@ -70,7 +70,6 @@ class DotNetSphinxMapper(SphinxMapperBase):
         pattern matches if no ``docfx.json`` files are found.
         """
         LOGGER.info(bold("[AutoAPI] ") + darkgreen("Loading Data"))
-        raise_error = kwargs.get("raise_error", True)
         all_files = set()
         if not self.app.config.autoapi_file_patterns:
             all_files = set(
@@ -82,35 +81,28 @@ class DotNetSphinxMapper(SphinxMapperBase):
             )
 
         if all_files:
-            try:
-                command = ["docfx", "metadata", "--raw", "--force"]
-                command.extend(all_files)
-                proc = subprocess.Popen(
-                    " ".join(command),
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE,
-                    shell=True,
-                    env=dict(
-                        (key, os.environ[key])
-                        for key in [
-                            "PATH",
-                            "HOME",
-                            "SYSTEMROOT",
-                            "USERPROFILE",
-                            "WINDIR",
-                        ]
-                        if key in os.environ
-                    ),
-                )
-                _, error_output = proc.communicate()
-                if error_output:
-                    LOGGER.warning(error_output)
-            except (OSError, subprocess.CalledProcessError):
-                LOGGER.warning("Error generating metadata", exc_info=True)
-                if raise_error:
-                    raise ExtensionError(
-                        "Failure in docfx while generating AutoAPI output."
-                    )
+            command = ["docfx", "metadata", "--raw", "--force"]
+            command.extend(all_files)
+            proc = subprocess.Popen(
+                " ".join(command),
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                shell=True,
+                env=dict(
+                    (key, os.environ[key])
+                    for key in [
+                        "PATH",
+                        "HOME",
+                        "SYSTEMROOT",
+                        "USERPROFILE",
+                        "WINDIR",
+                    ]
+                    if key in os.environ
+                ),
+            )
+            _, error_output = proc.communicate()
+            if error_output:
+                LOGGER.warning(error_output, type="autoapi", subtype="not_readable")
         # We now have yaml files
         for xdoc_path in self.find_files(
             patterns=["*.yml"], dirs=[self.DOCFX_OUTPUT_PATH], ignore=ignore
@@ -131,9 +123,17 @@ class DotNetSphinxMapper(SphinxMapperBase):
                 parsed_data = yaml.safe_load(handle)
                 return parsed_data
         except IOError:
-            LOGGER.warning("Error reading file: {0}".format(path))
+            LOGGER.warning(
+                "Error reading file: {0}".format(path),
+                type="autoapi",
+                subtype="not_readable",
+            )
         except TypeError:
-            LOGGER.warning("Error reading file: {0}".format(path))
+            LOGGER.warning(
+                "Error reading file: {0}".format(path),
+                type="autoapi",
+                subtype="not_readable",
+            )
         return None
 
     # Subclassed to iterate over items
@@ -172,6 +172,7 @@ class DotNetSphinxMapper(SphinxMapperBase):
         try:
             cls = obj_map[data["type"].lower()]
         except KeyError:
+            # this warning intentionally has no (sub-)type
             LOGGER.warning("Unknown type: %s" % data)
         else:
             obj = cls(
@@ -358,7 +359,7 @@ class DotNetPythonMapper(PythonMapperBase):
         Slugs to a filename using the follow steps
 
         * Decode unicode to approximate ascii
-        * Remove existing hypens
+        * Remove existing hyphens
         * Substitute hyphens for non-word characters
         * Break up the string as paths
         """
